@@ -1,11 +1,18 @@
-#[cfg(not(feature = "use_async"))]
+#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
+#[macro_use] extern crate lazy_static;
+
+#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
+#[macro_use] extern crate syslog_rs;
+
+#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
 pub mod example
 {
     use std::sync::Arc;
     use std::thread;
     use std::time::{Duration};
 
-    use syslog_rs::{Syslog, LogStat, LogFacility, Priority};
+    use syslog_rs::sy_sync::{Syslog};
+    use syslog_rs::{LogStat, LogFacility, Priority};
 
 
     lazy_static! {
@@ -39,18 +46,15 @@ pub mod example
 }
 
 
-#[cfg(not(feature = "use_async"))]
-#[macro_use] extern crate lazy_static;
 
-#[cfg(not(feature = "use_async"))]
-#[macro_use] extern crate syslog_rs;
-#[cfg(not(feature = "use_async"))]
+#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
 pub fn main()
 {
     use self::example::*;
+    main1();
     return;
 }
 
-#[cfg(feature = "use_async")]
+#[cfg(not(any(feature = "use_sync", feature = "use_sync_queue")))]
 fn main(){}
 
