@@ -172,6 +172,9 @@ pub const PATH_LOG_PRIV: &'static str = "/var/run/logpriv";
 /// backward compatibility
 pub const PATH_OLDLOG: &'static str = "/dev/log";
 
+/// OSX compat
+pub const PATH_OSX: &'static str = "/var/run/syslog";
+
 lazy_static! {
     /// path to the console dev
     pub static ref PATH_CONSOLE: CString = CString::new("/dev/console").unwrap();
