@@ -33,15 +33,18 @@
 //! - portable.rs - all system level code which is portable
 //! - common.rs - a common items
 //! - socket.rs - contains socket realization
+//! - async_socket.rs - contains socket realization
 //! - error.rs - an error wrapper and mapper
 //! 
 //! Features: 
-//! - feature = "use_async" for asynchronious code
-//! - feature = "use_sync" for synchronious code
-//! - feature = "use_sync_queue" for synchronious with async processing
+//! - feature = "use_async" for asynchronious code (use syslog_rs::sy_async::{Syslog};)
+//! - feature = "use_sync" for synchronious code (use syslog_rs::sy_sync::{Syslog};)
+//! - feature = "use_sync_queue" for synchronious with async processing (use syslog_rs::sy_async_queue::{Syslog};)
+//!
+//! All features can be used simultaniously.
 
 #[macro_use] extern crate bitflags;
-#[cfg(not(feature = "use_async"))]
+#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
 extern crate crossbeam;
 extern crate chrono;
 extern crate nix;
@@ -60,23 +63,20 @@ pub mod syslog_async;
 #[cfg(feature = "use_sync_queue")]
 pub mod syslog_sync_queue;
 
+#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
 pub mod socket;
+#[cfg(feature = "use_async")]
+pub mod async_socket;
+
 #[macro_use] pub mod common;
 #[macro_use] pub mod error;
 pub mod portable;
 
-#[cfg(all(feature = "use_sync", feature = "use_async"))]
-compile_error!("feature \"use_sync\" and feature \"use_async\" cannot be enabled at the same time");
-#[cfg(all(feature = "use_sync", feature = "use_sync_queue"))]
-compile_error!("feature \"use_sync\" and feature \"use_sync_queue\" cannot be enabled at the same time");
-#[cfg(all(feature = "use_async", feature = "use_sync_queue"))]
-compile_error!("feature \"use_async\" and feature \"use_sync_queue\" cannot be enabled at the same time");
-
 #[cfg(feature = "use_sync")]
-pub use syslog_sync::*;
+pub use syslog_sync as sy_sync;
 #[cfg(feature = "use_async")]
-pub use syslog_async::*;
+pub use syslog_async as sy_async;
 #[cfg(feature = "use_sync_queue")]
-pub use syslog_sync_queue::*;
+pub use syslog_sync_queue as sy_sync_queue;
 
 pub use common::*;
