@@ -19,21 +19,13 @@
 
 use std::{
     mem::MaybeUninit, 
-    /*os::unix::{
-        net::UnixDatagram, 
-        prelude::AsRawFd, 
-        io::RawFd
-    }*/
 };
 use std::sync::atomic::{AtomicBool, Ordering};
 use std::cell::RefCell;
-/*use std::net::Shutdown;
-use std::io::prelude::*;*/
 
 use crossbeam::utils::{Backoff, CachePadded};
 
-use chrono::offset::Local;
-//use nix::errno::Errno;
+use chrono::{offset::Local, SecondsFormat};
 
 //use crate::{map_error, throw_error};
 
@@ -362,7 +354,8 @@ impl Syslog
             };
 
         // get timedate
-        let timedate = Local::now().to_rfc3339();
+        let timedate = 
+            Local::now().to_rfc3339_opts(SecondsFormat::Secs, false);
 
         // get appname
         if self.option.exists_logtag() == true
@@ -374,7 +367,8 @@ impl Syslog
             }
         }
 
-        let progname = self.option.get_logtag().unwrap();
+        let b_progname = self.option.get_logtag();
+        let progname = b_progname.as_ref().unwrap();
         
 
         let msg = fmt.as_ref();
@@ -405,7 +399,7 @@ impl Syslog
         let mut msg = 
             [
                 // appname
-                " ".as_bytes(), progname.as_ref().as_bytes(), 
+                " ".as_bytes(), progname.as_bytes(), 
                 // PID
                 " ".as_bytes(), portable::get_pid().to_string().as_str().as_bytes(),
                 // message ID
@@ -413,9 +407,11 @@ impl Syslog
                 // structured data
                 " ".as_bytes(), NILVALUE.as_bytes(), 
                 // msg
-                " ".as_bytes(), b"\xEF\xBB\xBF", msg_final.as_bytes()
+                " ".as_bytes(), /*b"\xEF\xBB\xBF",*/ msg_final.as_bytes()
             ].concat();
         
+        drop(progname);
+
         // output to stderr if required
         self.option.send_to_stderr(&mut msg);
         
