@@ -30,7 +30,7 @@ use crossbeam::channel::{unbounded, Sender, Receiver};
 use crossbeam::deque::{Injector, Steal};
 use crossbeam::utils::{CachePadded};
 
-use chrono::offset::Local;
+use chrono::{offset::Local, SecondsFormat};
 //use nix::errno::Errno;
 
 //use crate::{map_error, throw_error};
@@ -483,7 +483,8 @@ impl SyslogInternal
             };
 
         // get timedate
-        let timedate = Local::now().to_rfc3339();
+        let timedate = 
+            Local::now().to_rfc3339_opts(SecondsFormat::Secs, false);
 
         // get appname
         if self.option.exists_logtag() == true
@@ -495,7 +496,8 @@ impl SyslogInternal
             }
         }
 
-        let progname = self.option.get_logtag().unwrap();
+        let b_progname = self.option.get_logtag();
+        let progname = b_progname.as_ref().unwrap();
         
 
         let msg = fmt.as_ref();
@@ -526,7 +528,7 @@ impl SyslogInternal
         let mut msg = 
             [
                 // appname
-                " ".as_bytes(), progname.as_ref().as_bytes(), 
+                " ".as_bytes(), progname.as_bytes(), 
                 // PID
                 " ".as_bytes(), portable::get_pid().to_string().as_str().as_bytes(),
                 // message ID
@@ -534,9 +536,11 @@ impl SyslogInternal
                 // structured data
                 " ".as_bytes(), NILVALUE.as_bytes(), 
                 // msg
-                " ".as_bytes(), b"\xEF\xBB\xBF", msg_final.as_bytes()
+                " ".as_bytes(), /*b"\xEF\xBB\xBF",*/ msg_final.as_bytes()
             ].concat();
         
+        drop(progname);
+
         // output to stderr if required
         self.option.send_to_stderr(&mut msg);
         
